==> guikachu-0.9.tar.gz: guikachu-0.9/src/mainwin.h <==
//$Id: mainwin.h,v 1.4 2001/04/01 18:16:03 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKATCHU_MAINWIN_H
#define GUIKATCHU_MAINWIN_H

namespace Guikachu
{
    namespace GUI
    {
	class MainWin;
	class TreeItem;
    }
}

#include <gnome--/app.h>
#include <gtk--/tree.h>
#include <gtk--/fileselection.h>
#include <map>
#include "resource.h"

namespace Guikachu
{
    namespace GUI
    {
	class MainWin: public Gnome::App
	{
	    typedef map<Resources::Type, Gtk::TreeItem*> subtree_map;
	    typedef map<Resources::Resource*, Guikachu::GUI::TreeItem*> treeitem_map;
	    
	    Gtk::Tree     *main_tree;
	    Gtk::TreeItem *top_item;
	    subtree_map    subtrees;
	    treeitem_map   treeitems;

	    string filename;
	    bool in_exit;
	    
	public:
	    MainWin ();
	    void set_filename (const string& filename);
	    
	private:
	    void create_tree_for_type (Resources::Type type,
				       const string& category_name);

	    void update_title ();
	    void resource_created_cb (Resources::Resource *res);
	    void resource_removed_cb (Resources::Resource *res);

	    virtual int delete_event_impl (GdkEventAny *e);
	    
	    void add_cb ();
	    void new_cb ();
	    void load_cb ();
	    void save_cb ();
	    void save_as_cb ();
	    void export_cb ();

	    void filesel_open_cb (Gtk::FileSelection *fs);
	    void filesel_save_cb (Gtk::FileSelection *fs);
	    void filesel_close_cb (Gtk::FileSelection *fs);
	    void filesel_export_cb (Gtk::FileSelection *fs);

	    bool check_save ();
	};

	void show_about ();
	void show_error (const string& message);
    }
}

#endif /* !GUIKATCHU_MAINWIN_H */

==> guikachu-0.13.tar.gz: guikachu-0.13/src/mainwin.h <==
//$Id: mainwin.h,v 1.5 2001/09/15 21:27:39 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_MAINWIN_H
#define GUIKACHU_MAINWIN_H

namespace Guikachu
{
    namespace GUI
    {
	class MainWin;
	class TreeItem;
    }
}

#include <gnome--/app.h>
#include <gtk--/tree.h>
#include <gtk--/fileselection.h>
#include <map>
#include "resource.h"

namespace Guikachu
{
    namespace GUI
    {
	class MainWin: public Gnome::App
	{
	    typedef map<Resources::Type, Gtk::TreeItem*> subtree_map;
	    typedef map<Resources::Resource*, Guikachu::GUI::TreeItem*> treeitem_map;
	    
	    Gtk::Tree     *main_tree;
	    Gtk::TreeItem *top_item;
	    subtree_map    subtrees;
	    treeitem_map   treeitems;

	    string filename;
	    bool in_exit;
	    
	public:
	    MainWin ();
	    void set_filename (const string& filename);
	    
	private:
	    void create_tree_for_type (Resources::Type type,
				       const string& category_name);

	    void update_title ();
	    void resource_created_cb (Resources::Resource *res);
	    void resource_removed_cb (Resources::Resource *res);

	    virtual int delete_event_impl (GdkEventAny *e);
	    
	    void add_cb ();
	    void new_cb ();
	    void load_cb ();
	    void save_cb ();
	    void save_as_cb ();
	    void export_cb ();

	    void filesel_open_cb (Gtk::FileSelection *fs);
	    void filesel_save_cb (Gtk::FileSelection *fs);
	    void filesel_close_cb (Gtk::FileSelection *fs);
	    void filesel_export_cb (Gtk::FileSelection *fs);

	    bool check_save ();
	};

	void show_about ();
	void show_error (const string& message);
    }
}

#endif /* !GUIKACHU_MAINWIN_H */
